@@ -33,16 +33,6 @@ extern struct superblock *sb_ptr;
   */
 extern struct fsck_agg_record *agg_recptr;
 
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * For message processing
-  *
-  *      defined in xchkdsk.c
-  */
-extern char *verbose_msg_ptr;
-
-extern char *Vol_Label;
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   * For directory entry processing
@@ -56,15 +46,6 @@ extern UniChar ukey[2][JFS_NAME_MAX];
 extern int32_t Uni_Name_len;
 extern UniChar Uni_Name[JFS_NAME_MAX];
 
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * Device information.
-  *
-  *      defined in xchkdsk.c
-  */
-extern HFILE Dev_IOPort;
-extern uint32_t Dev_blksize;
-
 /* VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV
  *
  * The following are internal to this file
@@ -432,7 +413,9 @@ int check_connectedness()
 							fsck_send_msg
 							    (fsck_INCINOREF,
 							     fsck_ref_msg(msg_info_ptr->msg_inopfx),
-							     msg_info_ptr->msg_inonum);
+							     msg_info_ptr->msg_inonum,
+							     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+							     this_inorec->parent_inonum);
 						}
 					}
 				}
