@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2005
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -125,6 +125,8 @@ struct btstack {
 		recon_dnode_put((dtpage_t *)BP);\
 }
 
+#define DO_INDEX() (sb_ptr->s_flag & JFS_DIR_INDEX)
+
 /* dtree split parameter */
 struct dtsplit {
 	struct btpage *bp;
@@ -165,7 +167,7 @@ static void ciGetLeafPrefixKey(dtpage_t * lp, int32_t li, dtpage_t * rp,
 
 #define ciToUpper(c)   UniStrupr((c)->name)
 
-static void dtInsertEntry(dtpage_t * p, int32_t index,
+static void dtInsertEntry(struct dinode *ip, dtpage_t * p, int32_t index,
 			  struct component_name *key, ddata_t * data);
 
 static void dtMoveEntry(dtpage_t * sp, int32_t si, dtpage_t * dp);
@@ -428,7 +430,7 @@ int fsck_dtInsert(struct dinode *ip, struct component_name *name,
 	/*
 	 *      insert entry for new key
 	 */
-	if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+	if (DO_INDEX())
 		n = NDTLEAF(name->namlen);
 	else
 		n = NDTLEAF_LEGACY(name->namlen);
@@ -456,7 +458,7 @@ int fsck_dtInsert(struct dinode *ip, struct component_name *name,
 	 *
 	 *      insert the new data entry into the leaf page;
 	 */
-	dtInsertEntry(p, index, name, &data);
+	dtInsertEntry(ip, p, index, name, &data);
 
 	/* unpin the leaf page */
 	FSCK_BT_PUTPAGE(bp);
@@ -722,7 +724,7 @@ static int dtSplitUp(struct dinode *ip, struct dtsplit *split,
 			/*
 			 * parent page is not full - insert router entry in parent page
 			 */
-			dtInsertEntry(sp, skip, &key, data);
+			dtInsertEntry(ip, sp, skip, &key, data);
 
 			/* exit propagate up */
 			break;
@@ -847,7 +849,7 @@ static int dtSplitPage(struct dinode *ip, struct dtsplit *split,
 		f->next = -1;
 
 		/* insert entry at the first entry of the new right page */
-		dtInsertEntry(rp, 0, split->key, split->data);
+		dtInsertEntry(ip, rp, 0, split->key, split->data);
 
 		goto out;
 	}
@@ -893,8 +895,7 @@ static int dtSplitPage(struct dinode *ip, struct dtsplit *split,
 			switch (sp->header.flag & BT_TYPE) {
 			case BT_LEAF:
 				ldtentry = (struct ldtentry *) &sp->slot[si];
-				if ((sb_ptr->s_flag & JFS_DIR_INDEX) ==
-				    JFS_DIR_INDEX)
+				if (DO_INDEX())
 					n = NDTLEAF(ldtentry->namlen);
 				else
 					n = NDTLEAF_LEGACY(ldtentry->namlen);
@@ -937,12 +938,23 @@ static int dtSplitPage(struct dinode *ip, struct dtsplit *split,
 		f->next = fsi;
 	f->next = -1;
 
+	/*
+	 * Update directory index table for entries now in right page
+	 */
+	if ((rp->header.flag & BT_LEAF) && DO_INDEX()) {
+		stbl = DT_GETSTBL(rp);
+		for (n = 0; n < rp->header.nextindex; n++) {
+			ldtentry = (struct ldtentry *) &rp->slot[stbl[n]];
+			modify_index(ip, rbn, n, ldtentry->index);
+		}
+	}
+
 	/*
 	 * the skipped index was on the left page,
 	 */
 	if (skip <= off) {
 		/* insert the new entry in the split page */
-		dtInsertEntry(sp, skip, split->key, split->data);
+		dtInsertEntry(ip, sp, skip, split->key, split->data);
 	} else {
 		/*
 		 * the skipped index was on the right page,
@@ -951,7 +963,7 @@ static int dtSplitPage(struct dinode *ip, struct dtsplit *split,
 		skip -= nxt;
 
 		/* insert the new entry in the right page */
-		dtInsertEntry(rp, skip, split->key, split->data);
+		dtInsertEntry(ip, rp, skip, split->key, split->data);
 	}
 
       out:
@@ -1074,11 +1086,23 @@ static int dtSplitRoot(struct dinode *ip, struct dtsplit *split,
 
 	rp->header.freecnt = sp->header.freecnt + rp->header.maxslot - n;
 
+	/*
+	 * Update directory index table for entries now in right page;
+	 */
+	if ((rp->header.flag & BT_LEAF) && DO_INDEX()) {
+		struct ldtentry *ldtentry;
+
+		stbl = DT_GETSTBL(rp);
+		for (n = 0; n < rp->header.nextindex; n++) {
+			ldtentry= (struct ldtentry *) &rp->slot[stbl[n]];
+			modify_index(ip, rbn, n, ldtentry->index);
+		}
+	}
 	/*
 	 * insert the new entry into the new right/child page
 	 * (skip index in the new right page will not change)
 	 */
-	dtInsertEntry(rp, split->index, split->key, split->data);
+	dtInsertEntry(ip, rp, split->index, split->key, split->data);
 
 	/*
 	 *      reset parent/root page
@@ -1172,6 +1196,20 @@ int fsck_dtDelete(struct dinode *ip, struct component_name *key, uint32_t * ino)
 		/* free the leaf entry */
 		fsck_dtDeleteEntry(p, index);
 
+		/*
+		 * Update directory index table for entries moved in stbl
+		 */
+		if (DO_INDEX() && index < p->header.nextindex) {
+			int i;
+			struct ldtentry *ldtentry;
+			int8_t *stbl;
+			stbl = DT_GETSTBL(p);
+			for (i = index; i < p->header.nextindex; i++) {
+				ldtentry = (struct ldtentry *)&p->slot[stbl[i]];
+				modify_index(ip, bn, i, ldtentry->index);
+			}
+		}
+
 		FSCK_BT_PUTPAGE(bp);
 	}
 
@@ -1451,7 +1489,7 @@ static int dtCompare(struct component_name *key,	/* search key */
 		si = lh->next;
 		name = lh->name;
 		namlen = lh->namlen;
-		if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+		if (DO_INDEX())
 			len = MIN(namlen, DTLHDRDATALEN);
 		else
 			len = MIN(namlen, DTLHDRDATALEN_LEGACY);
@@ -1552,7 +1590,7 @@ static int ciCompare(struct component_name *key,	/* search key */
 		si = lh->next;
 		name = lh->name;
 		namlen = lh->namlen;
-		if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+		if (DO_INDEX())
 			len = MIN(namlen, DTLHDRDATALEN);
 		else
 			len = MIN(namlen, DTLHDRDATALEN_LEGACY);
@@ -1692,7 +1730,7 @@ static void dtGetKey(dtpage_t * p, int32_t i,	/* entry index */
 		si = lh->next;
 		namlen = lh->namlen;
 		name = lh->name;
-		if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+		if (DO_INDEX())
 			len = MIN(namlen, DTLHDRDATALEN);
 		else
 			len = MIN(namlen, DTLHDRDATALEN_LEGACY);
@@ -1741,7 +1779,8 @@ static void dtGetKey(dtpage_t * p, int32_t i,	/* entry index */
  *
  * return: entry slot index
  */
-static void dtInsertEntry(dtpage_t * p,	/* directory page */
+static void dtInsertEntry(struct dinode *ip,
+			  dtpage_t * p,	/* directory page */
 			  int32_t index,	/* new entry index */
 			  struct component_name *key,	/* key */
 			  ddata_t * data)
@@ -1771,7 +1810,7 @@ static void dtInsertEntry(dtpage_t * p,	/* directory page */
 		lh->inumber = data->leaf.ino;
 		lh->namlen = klen;
 		name = lh->name;
-		if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX) {
+		if (DO_INDEX()) {
 			len = MIN(klen, DTLHDRDATALEN);
 			lh->index = 0;	/* Until we create index properly */
 		} else
@@ -1825,8 +1864,20 @@ static void dtInsertEntry(dtpage_t * p,	/* directory page */
 	/* if insert into middle, shift right succeeding entries in stbl */
 	stbl = DT_GETSTBL(p);
 	nextindex = p->header.nextindex;
-	if (index < nextindex)
+	if (index < nextindex) {
 		memmove(stbl + index + 1, stbl + index, nextindex - index);
+		/* Fix up directory index table */
+		if ((p->header.flag & BT_LEAF) && DO_INDEX()) {
+			int i;
+			int64_t bn = 0;
+			if (!(p->header.flag & BT_ROOT))
+				bn = addressPXD(&p->header.self);
+			for (i = index + 1; i <= nextindex; i++) {
+				lh = (struct ldtentry *) &(p->slot[stbl[i]]);
+				modify_index(ip, bn, i, lh->index);
+			}
+		}
+	}
 
 	stbl[index] = hsi;
 
@@ -1888,7 +1939,7 @@ static void dtMoveEntry(dtpage_t * sp,	/* src page */
 			slh = (struct ldtentry *) s;
 			snamlen = slh->namlen;
 
-			if ((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+			if (DO_INDEX())
 				len = MIN(snamlen, DTLHDRDATALEN);
 			else
 				len = MIN(snamlen, DTLHDRDATALEN_LEGACY);
