@@ -37,28 +37,6 @@ extern struct superblock *sb_ptr;
   */
 extern struct fsck_agg_record *agg_recptr;
 
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * For message processing
-  *
-  *      defined in xchkdsk.c
-  */
-extern UniChar uni_message_parm[];
-extern UniChar *uni_msgprm;
-
-extern char *verbose_msg_ptr;
-
-extern char *Vol_Label;
-
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * Device information.
-  *
-  *      defined in xchkdsk.c
-  */
-extern HFILE Dev_IOPort;
-extern uint32_t Dev_blksize;
-
 extern int32_t Uni_Name_len;
 extern UniChar Uni_Name[];
 extern int32_t Str_Name_len;
