@@ -35,25 +35,6 @@ extern struct superblock *sb_ptr;
   */
 extern struct fsck_agg_record *agg_recptr;
 
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * For message processing
-  *
-  *      defined in xchkdsk.c
-  */
-extern char *verbose_msg_ptr;
-
-extern char *Vol_Label;
-
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * Device information.
-  *
-  *      defined in xchkdsk.c
-  */
-extern HFILE Dev_IOPort;
-extern uint32_t Dev_blksize;
-
 /* VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV
  *
  * The following are internal to this file
