@@ -75,15 +75,6 @@ struct fsck_bmap_record *bmap_recptr;
 char *Vol_Label;
 char *program_name;
 
-UniChar uni_message_parm[MAXPARMLEN];
-UniChar *uni_msgprm = uni_message_parm;
-
-char message_buffer_1[1024];
-char message_buffer_2[1024];
-char *verbose_msg_ptr = &message_buffer_1[0];
-char *msgs_txt_ptr = &message_buffer_2[0];
-unsigned long msgs_txt_maxlen = 1024;
-
 struct tm *fsck_DateTime = NULL;
 char time_stamp[20];
 
@@ -107,7 +98,7 @@ char Str_Name[JFS_NAME_MAX];
  *
  *     values are assigned when (if) the device is opened.
  */
-HFILE Dev_IOPort;
+int Dev_IOPort;
 uint32_t Dev_blksize;
 int32_t Dev_SectorSize;
 char log_device[512] = { 0 };
@@ -419,6 +410,12 @@ int main(int argc, char **argv)
 		} else {
 			mapctl_flush();
 		}
+
+		if (rc == FSCK_OK) {
+			rc = flush_index_pages();
+		} else {
+			flush_index_pages();
+		}
 	}
 	/*
 	 * last chance to write to the wsp block map control page...
@@ -1016,8 +1013,8 @@ int final_processing()
 		/*
 		 * Make sure the s_logdev is up to date in the superblock.
 		 */
-		if ((log.location & OUTLINELOG) && log.devnum)
-			sb_ptr->s_logdev = log.devnum;
+		if ((Log.location & OUTLINELOG) && Log.devnum)
+			sb_ptr->s_logdev = Log.devnum;
 
 		/* refresh the redundancy of the
 		 * aggregate superblock (and verify
@@ -1998,9 +1995,9 @@ int phase0_processing()
 	 * If we're done, make sure s_logdev is up to date in the superblock.
 	 * Otherwise, s_logdev will be updated in final_processing.
 	 */
-	if (agg_recptr->fsck_is_done && (log.location & OUTLINELOG)
-	    && log.devnum) {
-		sb_ptr->s_logdev = log.devnum;
+	if (agg_recptr->fsck_is_done && (Log.location & OUTLINELOG)
+	    && Log.devnum) {
+		sb_ptr->s_logdev = Log.devnum;
 		/*
 		 * write the superblock to commit the above change
 		 */
@@ -2103,10 +2100,6 @@ int phase1_processing()
 	if (p1_rc != FSCK_OK) {
 		agg_recptr->fsck_is_done = 1;
 		exit_value = FSCK_OP_ERROR;
-		if (p1_rc > 0) {
-			/* this isn't a fsck failure */
-			p1_rc = 0;
-		}
 	}
 	return (p1_rc);
 }
@@ -2537,14 +2530,14 @@ int phase9_processing()
 		    jfs_logform(Dev_IOPort, sb_ptr->s_bsize, sb_ptr->s_l2bsize,
 				sb_ptr->s_flag, addressPXD(&(sb_ptr->s_logpxd)),
 				lengthPXD(&(sb_ptr->s_logpxd)), NULL, NULL);
-	} else if (log.fd && !uuid_is_null(sb_ptr->s_loguuid)) {
+	} else if (Log.fd && !uuid_is_null(sb_ptr->s_loguuid)) {
 		/* External log */
 		logformat_called = -1;
 #ifdef _JFS_DEBUG
 		printf("JFS fsck calling logformat \n");
 #endif
 		agg_recptr->logformat_rc =
-		    jfs_logform(log.fd, log.bsize, log.l2bsize,
+		    jfs_logform(Log.fd, Log.bsize, Log.l2bsize,
 				sb_ptr->s_flag, 0, 0, sb_ptr->s_loguuid, NULL);
 	} else
 		/* Extern log was never opened or null s_loguuid */
