@@ -78,7 +78,7 @@ struct FEALIST {		/* feal */
 
 #endif
 
-extern int jfs_ValidateFEAList(struct FEALIST *, unsigned long *);
+extern int jfs_ValidateFEAList(struct FEALIST *, int, unsigned long *);
 
 /* ***** IMPORTANT ***** IMPORTANT ***** IMPORTANT ***** IMPORTANT *****
  *
