@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2004
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,26 @@
 #include "fsckwsp.h"
 #include "jfs_endian.h"
 
+ /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
+  *
+  * Device information.
+  *
+  *      defined in xchkdsk.c
+  */
+extern int Dev_IOPort;
+extern uint32_t Dev_blksize;
+extern int32_t Dev_SectorSize;
+extern int64_t ondev_jlog_byte_offset;
+
+/*
+  ---------------------- functions defined in dirtable ---------------------
+*/
+
+int allocate_dir_index_buffers(void);
+
+void verify_dir_index(struct fsck_inode_record *, struct dinode *,
+		      struct dtreeQelem *, int, uint);
+
 /*
   ---------------------- functions defined in fsckbmap ---------------------
 */
@@ -82,6 +102,8 @@ int process_valid_dir_data(struct dinode *, uint32_t, struct fsck_inode_record *
 
 int reconnect_fs_inodes(void);
 
+int rebuild_dir_index(struct dinode *, struct fsck_inode_record *);
+
 /*
   ---------------------- functions defined in fsckimap ---------------------
 */
@@ -225,6 +247,8 @@ int dnode_get(int64_t, uint32_t, dtpage_t **);
 
 int ea_get(int64_t, uint32_t, char *, uint32_t *, uint32_t *, int64_t *);
 
+int flush_index_pages(void);
+
 int fscklog_put_buffer(void);
 
 int iag_get(int, int, int, int32_t, struct iag **);
@@ -257,6 +281,8 @@ int mapctl_put(void *);
 
 int mapctl_flush(void);
 
+void modify_index(struct dinode *, int64_t, int, uint);
+
 int node_get(int64_t, xtpage_t **);
 
 int open_volume(char *);
@@ -291,9 +317,9 @@ int alloc_wrksp(uint32_t, int, int, void **);	/* called from both fsck modules
 
 int blkall_decrement_owners(int64_t);
 
-int blkall_increment_owners(int64_t);
+int blkall_increment_owners(int64_t, int64_t, struct fsck_ino_msg_info *);
 
-int blkall_ref_check(int64_t, int *);
+int blkall_ref_check(int64_t, int64_t);
 
 int dire_buffer_alloc(dtpage_t **);
 
