@@ -66,10 +66,6 @@ char xchklog_buffer[XCHKLOG_BUFSIZE];
 extern char *msgprms[10];
 extern short msgprmidx[10];
 
-extern char message_buffer_0[512];
-extern char *msgs_txt_ptr;
-extern unsigned long msgs_txt_maxlen;
-
 /* VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV
  *
  * The following are internal to this file
