@@ -69,18 +69,15 @@ char xchklog_buffer[XCHKLOG_BUFSIZE];
   *
   *    values are assigned by the main jfs_fscklog routine
   */
-extern char message_buffer_0[512];
-extern char *msgs_txt_ptr;
-extern unsigned long msgs_txt_maxlen;
-
 extern char *Vol_Label;
+
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   * Device information.
   *
   *     values are assigned when (if) the device is opened.
   */
-HFILE Dev_IOPort;
+int Dev_IOPort;
 unsigned Dev_blksize;
 int Dev_SectorSize;
 
