@@ -15,8 +15,10 @@
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <sys/mount.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "jfs_types.h"
@@ -57,7 +59,7 @@
  *
  * RETURNS: 0 if successful; anything else indicates failures
  */
-int ujfs_get_dev_size(HFILE device, int64_t *size)
+int ujfs_get_dev_size(int device, int64_t *size)
 {
 
 	off_t Starting_Position;	/* position within file/device upon
@@ -268,7 +270,7 @@ restore:
  *
  * RETURNS:
  */
-int ujfs_rw_diskblocks(HFILE dev_ptr,
+int ujfs_rw_diskblocks(int dev_ptr,
 		       int64_t disk_offset, 
 		       int32_t disk_count, 
 		       void *data_buffer, 
@@ -296,6 +298,14 @@ int ujfs_rw_diskblocks(HFILE dev_ptr,
 	}
 
 	if (Bytes_Transferred != disk_count) {
+		if (Bytes_Transferred == -1)
+			perror("ujfs_rw_diskblocks");
+		else
+			fprintf(stderr,
+				"ujfs_rw_diskblocks: %s %zd of %d bytes at offset %lld\n",
+				(mode == GET) ? "read" : "wrote",
+				Bytes_Transferred, disk_count, disk_offset);
+
 		if (mode == GET)
 			return ERROR_READ_FAULT;
 		else
@@ -304,3 +314,11 @@ int ujfs_rw_diskblocks(HFILE dev_ptr,
 
 	return NO_ERROR;
 }
+
+int ujfs_flush_dev(int fd)
+{
+	if (fsync(fd) == -1)
+		return errno;
+
+	return ioctl(fd, BLKFLSBUF, 0);
+}
