@@ -26,10 +26,6 @@
 #define READONLY	0
 #define RDWR_EXCL	1
 
-/* Handle used to access the device. */
-#define HFILE  int
-#define PHFILE int *
-
 /* Error codes */
 #define NO_ERROR		0
 #define ERROR_INVALID_FUNCTION	1
@@ -44,6 +40,7 @@
 #define ERROR_INVALID_PARAMETER	87
 #define ERROR_DISK_FULL		112
 
-int ujfs_get_dev_size(HFILE device, int64_t * size);
-int ujfs_rw_diskblocks(HFILE, int64_t, int32_t, void *, int32_t);
+int ujfs_get_dev_size(int device, int64_t * size);
+int ujfs_rw_diskblocks(int, int64_t, int32_t, void *, int32_t);
+int ujfs_flush_dev(int);
 #endif				/* H_DEVICES */
