@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,12 +18,12 @@
 #ifndef H_DISKMAP
 #define H_DISKMAP
 
-#include <jfs_types.h>  /* int8_t, int32_t, int64_t, uint32_t */
+#include <jfs_types.h>		/* int8_t, int32_t, int64_t, uint32_t */
 
-int8_t   ujfs_maxbuddy(unsigned char *);
-int8_t   ujfs_adjtree(int8_t *, int32_t, int32_t);
-void     ujfs_complete_dmap(dmap_t *, int64_t, int8_t *);
-void     ujfs_idmap_page(dmap_t *, uint32_t);
-int32_t  ujfs_getagl2size(int64_t, int32_t);
+int8_t ujfs_maxbuddy(unsigned char *);
+int8_t ujfs_adjtree(int8_t *, int32_t, int32_t);
+void ujfs_complete_dmap(struct dmap *, int64_t, int8_t *);
+void ujfs_idmap_page(struct dmap *, uint32_t);
+int32_t ujfs_getagl2size(int64_t, int32_t);
 
-#endif	/* H_DISKMAP */
+#endif				/* H_DISKMAP */
