@@ -9,12 +9,10 @@ extern int dbg_output;
 #define fsck_ref_msg(msg_num) msg_defs[msg_num].msg_txt
 
 #define fsck_send_msg(msg_num, arg...) \
-	v_fsck_send_msg(msg_num, __FILE__, \
-			__LINE__, ## arg);
+	v_fsck_send_msg(msg_num, __FILE__ , __LINE__ , ## arg)
 
 #define send_msg(msg_num, arg...) \
-	v_send_msg(msg_num, __FILE__, \
-		   __LINE__, ## arg);
+	v_send_msg(msg_num, __FILE__ , __LINE__ , ## arg)
 
 // Define the maximum number of messages
 
@@ -24,13 +22,6 @@ extern int dbg_output;
 // Definition of constants for message flags
 
 #define avail_116              116
-#define avail_286              286
-#define avail_287              287
-#define avail_288              288
-#define avail_289              289
-#define avail_298              298
-#define avail_299              299
-#define avail_300              300
 #define avail_304              304
 #define avail_305              305
 #define avail_306              306
@@ -49,7 +40,6 @@ extern int dbg_output;
 #define avail_382              382
 #define avail_383              383
 
-#define avail_for_debug_only_589              589
 #define avail_for_debug_only_590              590
 #define avail_for_debug_only_591              591
 #define avail_for_debug_only_592              592
@@ -106,6 +96,8 @@ extern int dbg_output;
 #define fsck_ALLOCHIGHMEM             422
 #define fsck_ALLOCHIGHMEMRSLT         423
 
+#define fsck_BAD_COOKIE               286
+#define fsck_BAD_ENTRY                289
 #define fsck_BADAGFELIST               69
 #define fsck_BADAGFELIST1             196
 #define fsck_BADAGFILIST              197
@@ -267,6 +259,8 @@ extern int dbg_output;
 #define fsck_DEVOPENRDWRSRC           355
 #define fsck_DEVREDETERMRC             90
 #define fsck_DEVUNLOCKRC              129
+#define fsck_DI_TABLE                 298
+#define fsck_DI_TABLE_FXD             299
 #define fsck_DIRWHDLKS                 46
 #define fsck_DMAPBADNBLK              251
 #define fsck_DMAPBADNFREE             252
@@ -369,6 +363,7 @@ extern int dbg_output;
 
 #define fsck_NOTJFSINFSTAB            285
 
+#define fsck_PAGE_NOT_FOUND           287
 #define fsck_PARMAUTOCHK              333
 #define fsck_PARMCLRBDBLKLST          340
 #define fsck_PARMDEBUG                335
@@ -396,6 +391,8 @@ extern int dbg_output;
 #define fsck_PRMUNSUPPENUM            118
 #define fsck_PRMBADDEVICE	      371
 #define fsck_PRMNODEVICE	      372
+
+#define fsck_READ_FAILED              288
 #define fsck_READONLY                 370
 #define fsck_REPAIRSINPROGRESS        114
 #define fsck_RIBADDATFMT                2
@@ -442,6 +439,7 @@ extern int dbg_output;
 
 #define fsck_WILLCLEARACL             361
 #define fsck_WILLCLEAREA              111
+#define fsck_WILLFIX_DI_TABLE         300
 #define fsck_WILLFIXDIRWHDLKS         150
 #define fsck_WILLFIXINCREF            151
 #define fsck_WILLFIXINOMINOR          367
@@ -583,6 +581,7 @@ extern int dbg_output;
 #define lrdo_LRMWFAIL1                583
 #define lrdo_LRMWFAIL2                584
 #define lrdo_LRMWFAIL3                588
+#define lrdo_LOGINUSE                 589
 
 #define lrdo_MBMPBLKOUTRANGE          562
 #define lrdo_MOUNTRECORD              421
