@@ -27,10 +27,9 @@
 
 #define flog_eyecatcher_string "fscklog "
 
+
 struct fscklog_entry_hdr {
 	int16_t entry_length;
-	int16_t msg_num;
-	int16_t num_parms;
 };
 
 struct fscklog_error {
@@ -65,8 +64,6 @@ struct fscklog_error {
 
 struct chklog_entry_hdr {
 	int16_t entry_length;
-	int16_t msg_num;
-	int16_t num_parms;
 };
 
 #endif
