@@ -21,7 +21,7 @@
 #include <jfs_types.h>
 #include "devices.h"
 
-int ujfs_rwinode(HFILE, struct dinode *, uint32_t, int32_t, int32_t, uint32_t, uint32_t);
-int ujfs_rwdaddr(HFILE, int64_t *, struct dinode *, int64_t, int32_t, int32_t);
+int ujfs_rwinode(int, struct dinode *, uint32_t, int32_t, int32_t, uint32_t, uint32_t);
+int ujfs_rwdaddr(int, int64_t *, struct dinode *, int64_t, int32_t, int32_t);
 
 #endif
