@@ -116,27 +116,13 @@ void ujfs_swap_dinode(struct dinode *di, int32_t mode, uint32_t sb_flag)
 	if (ISDIR(di->di_mode)) {
 		/* cast di_btroot to dtree and swap it */
 		p = (dtpage_t *) & (di->di_btroot);
-		if (p->header.flag & BT_ROOT) {
-			/*
-			 * If inline dtpage is corrupt, byte-swapping can
-			 * really mess things up
-			 */
+		if (p->header.flag & BT_ROOT)
 			ujfs_swap_dtpage_t(p, sb_flag);
-			if (mode == GET) {
-				p->header.flag |= BT_SWAPPED;
-			} else if (mode == PUT) {
-				p->header.flag &= ~BT_SWAPPED;
-			}
-		}
 
 		if ((sb_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX) {
-			if (di->di_next_index > MAX_INLINE_DIRTABLE_ENTRY)
+			if (di->di_next_index > MAX_INLINE_DIRTABLE_ENTRY + 1)
 				/* cast di_dirtable to xtree and swap it */
 				ujfs_swap_xtpage_t((xtpage_t *) & (di->di_dirtable));
-			else
-				for (i = 0; i < MAX_INLINE_DIRTABLE_ENTRY - 1; i++)
-					di->u._dir._table[i].addr2 =
-					    __le32_to_cpu(di->u._dir._table[i].addr2);
 		}
 	} else if (ISREG(di->di_mode) || ISLNK(di->di_mode)) {
 		/* cast di_btroot to xtree and swap it */
