@@ -233,8 +233,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 		 * aggregate block size is for log file as well.
 		 */
 
-		rc = ujfs_rw_diskblocks(log.fd,
-					(uint64_t) (log.xaddr + LOGPNTOB(LOGSUPER_B)),
+		rc = ujfs_rw_diskblocks(Log.fd,
+					(uint64_t) (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 					(unsigned) sizeof (struct logsuper), (char *) &logsup, GET);
 		if (rc != 0) {
 			printf("JFS_LOGDUMP:couldn't read log superblock:failure in %s\n", prog);
@@ -287,8 +287,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 			fprintf(outfp, "\n");
 		}
 
-		log.size = logsup.size;
-		log.serial = logsup.serial;
+		Log.size = logsup.size;
+		Log.serial = logsup.serial;
 
 		/*
 		 * find the end of log
@@ -298,8 +298,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 			printf("logend < 0\n");
 			ldmp_logError(LOGEND, 0);
 			ujfs_swap_logsuper(&logsup);
-			rc = ujfs_rw_diskblocks(log.fd,
-						(uint64_t) (log.xaddr + LOGPNTOB(LOGSUPER_B)),
+			rc = ujfs_rw_diskblocks(Log.fd,
+						(uint64_t) (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 						(unsigned long) LOGPSIZE, (char *) &logsup, PUT);
 			rc = logend;
 			goto loopexit;
