@@ -41,14 +41,6 @@
 
 #include "fsck_message.h"		/* for fsck message logging facility */
 
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * For the fsck message logging facility
-  *
-  *      defined in xchkdsk.c
-  */
-extern char *verbose_msg_ptr;
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   *    R E M E M B E R    M E M O R Y    A L L O C    F A I L U R E
