@@ -1,4 +1,6 @@
 /*
+ *   Copyright (c) International Business Machines Corp., 2000-2002
+ *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or 
@@ -13,12 +15,9 @@
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 #ifndef H_LOGFORM
 #define H_LOGFORM
 
-#include <uuid/uuid.h>
-
-int jfs_logform(int, int, int, uint, int64_t, int, uuid_t);
+int jfs_logform(int, int, int, uint, int64_t, int, uuid_t, char *);
 
 #endif				/* H_LORFORM */
