@@ -42,14 +42,6 @@
 
 #include "fsck_message.h"		/* for chkdsk message logging facility */
 
-/* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
- *
- * For the chkdsk message logging facility
- *
- *      defined in xchkdsk.c
- */
-extern char *verbose_msg_ptr;
-
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  *   L O C A L   M A C R O    D E F I N I T I O N S
@@ -110,7 +102,7 @@ int32_t numExtDtPg = 0;		/* number of extended dtpage blocks used  */
  *
  */
 struct vopen vopen[MAX_ACTIVE];
-struct log_info log;
+struct log_info Log;
 struct {
 	uuid_t uuid;
 	int fd;
@@ -510,7 +502,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	}
 
 	/* recover from extendfs() ? */
-	if (log.location & INLINELOG && (vopen[0].status & FM_EXTENDFS)) {
+	if (Log.location & INLINELOG && (vopen[0].status & FM_EXTENDFS)) {
 		fsck_send_msg(lrdo_REXTNDBEGIN);
 		rc = recoverExtendFS(fd);
 		fsck_send_msg(lrdo_REXTNDDONE);
@@ -522,8 +514,8 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 *
 	 * aggregate block size is for log file as well.
 	 */
-	rc = ujfs_rw_diskblocks(log.fd,
-				(uint64_t) (log.xaddr +
+	rc = ujfs_rw_diskblocks(Log.fd,
+				(uint64_t) (Log.xaddr +
 					    LOGPNTOB(LOGSUPER_B)),
 				(unsigned) sizeof (struct logsuper), (char *) &logsup, GET);
 	if (rc != 0) {
@@ -545,13 +537,13 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		goto error_out;
 	}
 
-	if (log.location & OUTLINELOG) {
+	if (Log.location & OUTLINELOG) {
 		struct stat st;
 
-		if ((rc = fstat(log.fd, &st)))
+		if ((rc = fstat(Log.fd, &st)))
 			goto error_out;
 
-		log.devnum = st.st_rdev;
+		Log.devnum = st.st_rdev;
 
 		if (in_use) {
 			fsck_send_msg(lrdo_LOGINUSE);
@@ -561,7 +553,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 
 	if (logsup.state == LOGREDONE) {
 		fsck_send_msg(lrdo_ALREADYREDONE);
-		if (log.location & INLINELOG)
+		if (Log.location & INLINELOG)
 			if ((rc = updateSuper(0)) != 0) {
 				fsck_send_msg(lrdo_CANTUPDLOGSUP);
 				return (rc);
@@ -569,8 +561,8 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		return (0);
 	}
 
-	log.size = logsup.size;
-	log.serial = logsup.serial;
+	Log.size = logsup.size;
+	Log.serial = logsup.serial;
 
 	/*
 	 * find the end of log
@@ -583,8 +575,8 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		fsck_send_msg(lrdo_LOGENDBAD1);
 		logError(LOGEND, 0);
 		ujfs_swap_logsuper(&logsup);
-		rc = ujfs_rw_diskblocks(log.fd,
-					(log.xaddr + LOGPNTOB(LOGSUPER_B)),
+		rc = ujfs_rw_diskblocks(Log.fd,
+					(Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 					(unsigned long) LOGPSIZE, (char *) &logsup, PUT);
 		rc = logend;
 		goto error_out;
@@ -791,20 +783,23 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		if (vopen[k].state != VOPEN_OPEN)
 			continue;
 
-		/* don't update the maps if the aggregate/lv is
-		 * FM_DIRTY since fsck will rebuild maps anyway
-		 */
-		if (!vopen[k].is_fsdirty) {
-			if ((rc = updateMaps(k)) != 0) {
-				fsck_send_msg(lrdo_ERRORCANTUPDMAPS);
-				goto error_out;
-			}
+		if ((rc = updateMaps(k)) != 0) {
+			fsck_send_msg(lrdo_ERRORCANTUPDMAPS);
+			goto error_out;
 		}
 
+		/* Make sure all changes are committed to disk before we
+		 * mark the superblock clean
+		 */
+		fsync(vopen[k].fd);
+
 		if ((rc = updateSuper(k)) != 0) {
 			fsck_send_msg(lrdo_ERRORCANTUPDFSSUPER);
 			goto error_out;
 		}
+
+		/* sync superblock before journal is finalized */
+		fsync(vopen[k].fd);
 	}
 
 	/*
@@ -824,7 +819,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		logsup.magic = LOGMAGIC;
 	}
 	ujfs_swap_logsuper(&logsup);
-	rc = ujfs_rw_diskblocks(log.fd, (log.xaddr + LOGPNTOB(LOGSUPER_B)),
+	rc = ujfs_rw_diskblocks(Log.fd, (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 				LOGPSIZE, (char *) &logsup, PUT);
 
 	/*
@@ -899,7 +894,7 @@ int openVol(int vol)
 	struct superblock sb;
 	int aggsb_numpages;
 
-	if (log.location & OUTLINELOG) {
+	if (Log.location & OUTLINELOG) {
 		/* First check if this is the already opened volume */
 		if (!uuid_compare(vopen[vol].uuid, primary_vol.uuid))
 			vopen[vol].fd = primary_vol.fd;
@@ -934,7 +929,7 @@ int openVol(int vol)
 		return (LOGSUPER_BADVERSION);
 	}
 
-	if (log.location & OUTLINELOG && (sb.s_flag & (JFS_INLINELOG == JFS_INLINELOG))) {
+	if (Log.location & OUTLINELOG && (sb.s_flag & (JFS_INLINELOG == JFS_INLINELOG))) {
 		fsck_send_msg(lrdo_FSSUPERBADLOGLOC);
 		vopen[vol].state = VOPEN_CLOSED;
 		return (LOGSUPER_BADLOGLOC);
@@ -954,7 +949,7 @@ int openVol(int vol)
 		vopen[vol].numag += 1;
 	vopen[vol].l2agsize = l2agsize;
 
-	if (log.location & INLINELOG) {
+	if (Log.location & INLINELOG) {
 		/*
 		 * Now that the aggregate superblock has been read, do some
 		 * more validation of the log superblock
@@ -998,7 +993,7 @@ int openVol(int vol)
 	/*
 	 *check log serial number
 	 */
-	if (sb.s_logserial != log.serial) {
+	if (sb.s_logserial != Log.serial) {
 		fsck_send_msg(lrdo_FSSUPERBADLOGSER);
 		vopen[vol].state = VOPEN_CLOSED;
 		fsError(SERIALNO, vol, SUPER1_B);
@@ -1195,11 +1190,11 @@ int findLog(int fd, int *in_use)
 		 * does file system contains its in-line log ?
 		 */
 		if ((sb.s_flag & JFS_INLINELOG) == JFS_INLINELOG) {
-			log.location = INLINELOG;
-			log.fd = fd;
-			//log.status = sb.s_state;
-			log.l2bsize = sb.s_l2bsize;
-			log.xaddr = addressPXD(&sb.s_logpxd) << sb.s_l2bsize;
+			Log.location = INLINELOG;
+			Log.fd = fd;
+			//Log.status = sb.s_state;
+			Log.l2bsize = sb.s_l2bsize;
+			Log.xaddr = addressPXD(&sb.s_logpxd) << sb.s_l2bsize;
 
 			/* vopen[0] represents fs if inline log */
 			vopen[0].status = sb.s_state;
@@ -1217,34 +1212,34 @@ int findLog(int fd, int *in_use)
 		 * First check device specified on
 		 * command line
 		 */
-		log.xaddr = 0;
+		Log.xaddr = 0;
 		if (log_device[0]) {
-			log.fd = open(log_device, LogOpenMode, 0);
-			if (log.fd < 0) {
-				log.fd = open(log_device, O_RDONLY, 0);
-				if (log.fd < 0) {
+			Log.fd = open(log_device, LogOpenMode, 0);
+			if (Log.fd < 0) {
+				Log.fd = open(log_device, O_RDONLY, 0);
+				if (Log.fd < 0) {
 					printf("Invalid journal specified (%s)\n",
 					       log_device);
 					goto by_uuid;
 				}
 				*in_use = 1;
 			}
-			ujfs_rw_diskblocks(log.fd, LOGPNTOB(LOGSUPER_B),
+			ujfs_rw_diskblocks(Log.fd, LOGPNTOB(LOGSUPER_B),
 					   sizeof (struct logsuper), &logsup, GET);
 			ujfs_swap_logsuper(&logsup);
 			if ((logsup.magic != LOGMAGIC) || (uuid_compare(logsup.uuid, sb.s_loguuid))) {
-				close(log.fd);
+				close(Log.fd);
 				*in_use = 0;
 				goto by_uuid;
 			}
-			log.location = OUTLINELOG;
+			Log.location = OUTLINELOG;
 			return 0;
 		}
 	      by_uuid:
-		log.fd = open_by_label(sb.s_loguuid, 0, 1, NULL, in_use);
+		Log.fd = open_by_label(sb.s_loguuid, 0, 1, NULL, in_use);
 
-		if (log.fd >= 0) {
-			log.location |= OUTLINELOG;
+		if (Log.fd >= 0) {
+			Log.location |= OUTLINELOG;
 			return 0;
 		}
 
@@ -1259,8 +1254,8 @@ int findLog(int fd, int *in_use)
 		fsck_send_msg(lrdo_NOTAFSDEV);
 		return NOT_FSDEV_ERROR;
 	}
-	log.fd = fd;
-	log.location = OUTLINELOG;
+	Log.fd = fd;
+	Log.location = OUTLINELOG;
 
 	return 0;
 }
@@ -1572,7 +1567,7 @@ static int recoverExtendFS(int32_t fd)
 	 * marked as free by extendfs();
 	 */
 	/* fake log opend/validated */
-	log.serial = sbp->s_logserial;
+	Log.serial = sbp->s_logserial;
 
 	/*
 	 *  reconstruct maps
