@@ -200,7 +200,7 @@ struct log_info {
 	uuid_t uuid;		/* 128-bit device uuid */
 	int32_t devnum;		/* Kernel-style device number */
 };
-extern struct log_info log;
+extern struct log_info Log;
 
 /*
  *      open file system aggregate/lv array
