@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -15,18 +15,17 @@
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include "jfs_endian.h"
 #include "jfs_types.h"
-#include "jfs_filsys.h" 
-#include "jfs_superblock.h" 
-#include "libjufs.h" 
-#include "devices.h" 
-#include "jfs_dmap.h" 
+#include "jfs_filsys.h"
+#include "jfs_superblock.h"
+#include "libjufs.h"
+#include "devices.h"
+#include "jfs_dmap.h"
 #include "utilsubs.h"
 #include <errno.h>
 
@@ -48,21 +47,18 @@
  *
  * RETURNS: If it is, it returns 1, else 0
  */
-int32_t inrange( uint32_t  num,
-                 uint32_t  low,
-                 uint32_t  high )
+int inrange(uint32_t num, uint32_t low, uint32_t high)
 {
-    if( low ) {
-        for( ; low <= high; low <<= 1 ) {
-            if( low == num ) {
-                return 1;
-            }
-        }
-    }
-    return 0;
+	if (low) {
+		for (; low <= high; low <<= 1) {
+			if (low == num) {
+				return 1;
+			}
+		}
+	}
+	return 0;
 }
 
-
 /*
  * NAME: validate_sizes
  *
@@ -86,19 +82,18 @@ int32_t inrange( uint32_t  num,
  *      success: 0
  *      failure:  any other value
  */
-static int32_t validate_sizes( struct superblock *sb )
+static int validate_sizes(struct superblock *sb)
 {
-    /*
-     * Make sure AG size is at least 32M
-     */
-    if( sb->s_agsize >= (1 << L2BPERDMAP) ) {
-        return 0;
-    }
+	/*
+	 * Make sure AG size is at least 32M
+	 */
+	if (sb->s_agsize >= (1 << L2BPERDMAP)) {
+		return 0;
+	}
 
-    return EINVAL;
+	return EINVAL;
 }
 
-
 /*
  * NAME: ujfs_validate_super
  *
@@ -121,20 +116,19 @@ static int32_t validate_sizes( struct superblock *sb )
  *      success: 0
  *      failure: LIBFS_CORRUPTSUPER, LIBFS_BADVERSION, LIBFS_BADMAGIC
  */
-int32_t ujfs_validate_super( struct superblock *sb )
+int ujfs_validate_super(struct superblock *sb)
 {
-    if( memcmp(sb->s_magic, JFS_MAGIC, sizeof(sb->s_magic)) == 0 ) {
-        if( sb->s_version > JFS_VERSION )
-            return LIBFS_BADVERSION;
-        if( validate_sizes(sb) == EINVAL )
-            return LIBFS_CORRUPTSUPER;
-    } else {
-        return LIBFS_BADMAGIC;
-    }
-    return 0;
+	if (memcmp(sb->s_magic, JFS_MAGIC, sizeof (sb->s_magic)) == 0) {
+		if (sb->s_version > JFS_VERSION)
+			return LIBFS_BADVERSION;
+		if (validate_sizes(sb) == EINVAL)
+			return LIBFS_CORRUPTSUPER;
+	} else {
+		return LIBFS_BADMAGIC;
+	}
+	return 0;
 }
 
-
 /*
  * NAME: ujfs_put_superblk
  *
@@ -164,26 +158,23 @@ int32_t ujfs_validate_super( struct superblock *sb )
  *      success: 0
  *      failure: any other value
  */
-int32_t ujfs_put_superblk( HFILE              fd,
-                           struct superblock  *sb,
-                           int16_t            is_primary )
+int ujfs_put_superblk(int fd, struct superblock *sb, int16_t is_primary)
 {
-    char     buf[SIZE_OF_SUPER];
-    int32_t  rc;
+	char buf[SIZE_OF_SUPER];
+	int rc;
 
-    memset( buf, 0, SIZE_OF_SUPER );
-    memcpy( buf, sb, sizeof(*sb) );
+	memset(buf, 0, SIZE_OF_SUPER);
+	memcpy(buf, sb, sizeof (*sb));
 
-    /* swap if on big endian machine */
-    ujfs_swap_superblock( (struct superblock *)buf );
+	/* swap if on big endian machine */
+	ujfs_swap_superblock((struct superblock *) buf);
 
-    rc = ujfs_rw_diskblocks( fd, (is_primary ? SUPER1_OFF : SUPER2_OFF),
-                             SIZE_OF_SUPER, buf, PUT );
+	rc = ujfs_rw_diskblocks(fd, (is_primary ? SUPER1_OFF : SUPER2_OFF),
+				SIZE_OF_SUPER, buf, PUT);
 
-    return rc;
+	return rc;
 }
 
-
 /*
  * NAME: ujfs_get_superblk
  *
@@ -210,21 +201,133 @@ int32_t ujfs_put_superblk( HFILE              fd,
  *      success: 0
  *      failure: any other value
  */
-int32_t ujfs_get_superblk( HFILE              fd,
-                           struct superblock  *sb,
-                           int32_t            is_primary )
+int ujfs_get_superblk(int fd, struct superblock *sb, int32_t is_primary)
 {
-    int32_t  rc;
-    char     buf[SIZE_OF_SUPER];
-    struct superblock  *sblk = (struct superblock *)buf;
+	int rc;
+	char buf[SIZE_OF_SUPER];
+	struct superblock *sblk = (struct superblock *) buf;
 
-    rc = ujfs_rw_diskblocks( fd, (is_primary ? SUPER1_OFF : SUPER2_OFF),
-                             SIZE_OF_SUPER, sblk, GET );
+	rc = ujfs_rw_diskblocks(fd, (is_primary ? SUPER1_OFF : SUPER2_OFF),
+				SIZE_OF_SUPER, sblk, GET);
 
-    ujfs_swap_superblock( sblk );
+	ujfs_swap_superblock(sblk);
 
-    if( rc != 0 ) return rc;
+	if (rc != 0)
+		return rc;
 
-    memcpy( sb, sblk, sizeof(*sb) );
-    return 0;
+	memcpy(sb, sblk, sizeof (*sb));
+	return 0;
+}
+
+/*
+ * NAME: ujfs_validate_logsuper
+ *
+ * FUNCTION: Check if log superblock is valid
+ *
+ * PRE CONDITIONS:
+ *
+ * POST CONDITIONS:
+ *
+ * PARAMETERS:
+ *      logsup - log superblock to validate
+ *
+ * NOTES:
+ *
+ * RECOVERY OPERATION:
+ *
+ * DATA STRUCTURES:
+ *
+ * RETURNS:
+ *      success: 0
+ *      failure: LIBFS_BADVERSION, LIBFS_BADMAGIC
+ */
+int ujfs_validate_logsuper(struct logsuper *logsup)
+{
+	/* see if superblock is JFS log superblock */
+	if (logsup->magic == LOGMAGIC) {
+		if (logsup->version != LOGVERSION) {
+			return LIBFS_BADVERSION;
+		}
+	} else {
+		return LIBFS_BADMAGIC;
+	}
+
+	return 0;
+}
+
+/*
+ * NAME: ujfs_put_logsuper
+ *
+ * FUNCTION: Write log superblock to disk
+ *
+ * PRE CONDITIONS:
+ *
+ * POST CONDITIONS:
+ *
+ * PARAMETERS:
+ *      fd      - open port for device to write superblock to
+ *      logsup  - pointer to log superblock to be written
+ *
+ * NOTES: 
+ *
+ * RECOVERY OPERATION:
+ *
+ * DATA STRUCTURES:
+ *
+ * RETURNS:
+ *      success: 0
+ *      failure: any other value
+ */
+int ujfs_put_logsuper(int fd, struct logsuper *logsup)
+{
+	char buf[sizeof (struct logsuper)];
+	int rc = 0;
+
+	memcpy(buf, logsup, sizeof (struct logsuper));
+
+	/* swap if on big endian machine */
+	ujfs_swap_logsuper((struct logsuper *) buf);
+
+	rc = ujfs_rw_diskblocks(fd, LOGPSIZE, sizeof (struct logsuper), buf, PUT);
+
+	return rc;
+}
+
+/*
+ * NAME: ujfs_get_logsuper
+ *
+ * FUNCTION: read the log superblock from the specified device
+ *
+ * PRE CONDITIONS:
+ *
+ * POST CONDITIONS:
+ *
+ * PARAMETERS:
+ *      fd      - open port for device to read superblock from
+ *      logsup  - pointer to log superblock to be filled in on return
+ *
+ * NOTES:
+ *
+ * RECOVERY OPERATION:
+ *
+ * DATA STRUCTURES:
+ *
+ * RETURNS:
+ *      success: 0
+ *      failure: any other value
+ */
+int ujfs_get_logsuper(int fd, struct logsuper *logsup)
+{
+	int rc = 0;
+	char buf[sizeof (struct logsuper)];
+	struct logsuper *logsup_buf = (struct logsuper *) buf;
+
+	rc = ujfs_rw_diskblocks(fd, LOGPSIZE, sizeof (struct logsuper), logsup_buf, GET);
+
+	if (!rc) {
+		ujfs_swap_logsuper(logsup_buf);
+		memcpy(logsup, logsup_buf, sizeof (struct logsuper));
+	}
+
+	return rc;
 }
