@@ -32,10 +32,6 @@
 
 extern short MsgProtocol[][2];
 
-extern char *Vol_Label;
-
-extern char *verbose_msg_ptr;
-
 extern char *msgprms[];
 extern short msgprmidx[];
 
