@@ -52,7 +52,7 @@ char log_device[1];		/* This avoids linker error */
   *
   *     values are assigned when (if) the device is opened.
   */
-HFILE Dev_IOPort;
+int Dev_IOPort;
 unsigned Dev_blksize;
 
 char *Vol_Label = NULL;
@@ -65,13 +65,6 @@ int dump_all = 0;
   *
   */
 
-char message_buffer_0[256];
-char message_buffer_1[1024];
-char message_buffer_2[1024];
-char *verbose_msg_ptr = &message_buffer_1[0];
-char *msgs_txt_ptr = &message_buffer_2[0];
-unsigned long msgs_txt_maxlen = 1024;
-
 extern caddr_t prog;
 
 extern void fsck_send_msg(int, int);	/* defined in fsckmsg.c */
