@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2005
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -15,11 +15,14 @@
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#define _GNU_SOURCE	/* FOR O_DIRECT */
 #include "jfs_types.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <unistd.h>
+#include <fcntl.h>
 #include <errno.h>
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
@@ -55,7 +58,7 @@ struct xtree_buf {
 
 static struct xtree_buf *badblock_pages;
 
-static int xtAppend(HFILE, struct dinode *, int64_t, int64_t, int,
+static int xtAppend(int, struct dinode *, int64_t, int64_t, int,
 		    struct xtree_buf *, int);
 
 /*--------------------------------------------------------------------
@@ -670,7 +673,7 @@ int write_block_map(int dev_ptr, int64_t number_of_blocks, int aggr_block_size)
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int dbAlloc(HFILE dev_ptr, int64_t xlen, int64_t * xaddr)
+static int dbAlloc(int dev_ptr, int64_t xlen, int64_t * xaddr)
 {
 	int rc = 0;
 	int page, word;
@@ -780,7 +783,7 @@ static int dbAlloc(HFILE dev_ptr, int64_t xlen, int64_t * xaddr)
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int xtSplitRoot(HFILE dev_ptr,
+static int xtSplitRoot(int dev_ptr,
 		       struct dinode *ip,
 		       struct xtree_buf *xroot,
 		       int64_t offset, int nblocks, int64_t blkno)
@@ -885,7 +888,7 @@ static int xtSplitPage(struct dinode *ip,
 		       struct xtree_buf *xpage,
 		       int64_t offset,
 		       int nblocks,
-		       int64_t blkno, HFILE dev_ptr, int aggr_block_size)
+		       int64_t blkno, int dev_ptr, int aggr_block_size)
 {
 	int rc = 0;
 	int64_t xaddr;		/* new right page block number */
@@ -968,7 +971,7 @@ static int xtSplitPage(struct dinode *ip,
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int xtAppend(HFILE dev_ptr,
+static int xtAppend(int dev_ptr,
 		    struct dinode *di,
 		    int64_t offset,
 		    int64_t blkno,
@@ -1081,13 +1084,14 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 {
 	int rc = 0;
 	int error;
-	char *buffer = NULL;
+	void *buffer = NULL;
 	int bufsize = PSIZE << 5, nbufblks;
 	int64_t nblocks, nb;
 	int64_t blkno, thisblk;
 	int percent, section, index;
 	bool write_inode = false;
 	struct xtree_buf *curpage;
+	long flags;
 
 	if (badblock_pages == NULL) {
 		/*
@@ -1103,16 +1107,23 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 	}
 
 	/* Allocate and clear a buffer */
-	while ((bufsize >= aggr_block_size)
-	       && ((buffer = calloc(bufsize, sizeof (char))) == NULL))
+	while ((bufsize >= aggr_block_size) &&
+	       posix_memalign(&buffer, aggr_block_size, bufsize))
 		bufsize >>= 1;
 
 	if (buffer == NULL) {
 		message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
 		return (ENOMEM);
 	}
+	memset(buffer, 0, bufsize);
 	nbufblks = bufsize / aggr_block_size;
 
+	/*
+	 * Must do direct-io to avoid the page cache
+	 */
+	flags = fcntl(dev_ptr, F_GETFL);
+	fcntl(dev_ptr, F_SETFL, flags | O_DIRECT);
+
 	/*
 	 * Starting from the last allocated block to the end of the aggregate 
 	 * write the empty buffer to disk.
@@ -1175,6 +1186,9 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 				}
 
 				if (error != 0) {
+					/* add_bad_block may do unaligned I/O */
+					fcntl(dev_ptr, F_SETFL, flags);
+
 					/* Add this block to bad list */
 					if ((rc =
 					     add_bad_block(dev_ptr, thisblk,
@@ -1182,6 +1196,8 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 							   bb_inode)))
 						continue;
 					write_inode = true;
+					fcntl(dev_ptr, F_SETFL,
+					      flags | O_DIRECT);
 
 					/*
 					 * In case we allocated blocks for our 
@@ -1211,6 +1227,8 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 			nblocks -= nb;
 		}
 	}
+	fcntl(dev_ptr, F_SETFL, flags);
+
 	msg_parms[0] = "100";
 	message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, OSO_MSG);
 	fprintf(stdout, "\n");
