@@ -22,9 +22,9 @@
 
 typedef enum { inline_data, extent_data, max_extent_data, no_data } ino_data_type;
 
-int init_aggr_inode_table(int, HFILE, struct dinode *, int, int64_t, int64_t, int, unsigned);
-int init_fileset_inode_table(int, HFILE, int64_t *, int *, int64_t, int64_t, unsigned);
-int init_fileset_inodes(int, HFILE, int64_t, int, int64_t, unsigned);
+int init_aggr_inode_table(int, int, struct dinode *, int, int64_t, int64_t, int, unsigned);
+int init_fileset_inode_table(int, int, int64_t *, int *, int64_t, int64_t, unsigned);
+int init_fileset_inodes(int, int, int64_t, int, int64_t, unsigned);
 
 void init_inode(struct dinode *, int, unsigned, int64_t, int64_t, int64_t, mode_t,
 		ino_data_type, int64_t, int, unsigned);
