@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2005
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -76,7 +76,8 @@ static struct dinode aggr_inodes[INIT_NUM_AGGR_INODES];
 void mkfs_usage()
 {
 	printf("\nUsage:  %s [-cOqV] [-j log_device] [-J options] "
-	       "[-L vol_label] [-s log_size] device\n", program_name);
+	       "[-L vol_label] [-s log_size] device [ blocks ]\n",
+	       program_name);
 	printf("\nEmergency help:\n"
 	       " -c            Check device for bad blocks before building file system.\n"
 	       " -O            Provide case-insensitive support for OS/2 compatability.\n"
@@ -556,7 +557,7 @@ static int create_aggregate(int dev_ptr,
  *      success: 0
  *      failure: any other value
  */
-static int Bad_Device(HFILE Device_Handle)
+static int Bad_Device(int Device_Handle)
 {
 
 	struct stat stat_data;
@@ -696,10 +697,11 @@ int main(int argc, char *argv[])
         char volume_label[16] = { "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" };
 	int64_t number_of_bytes = 0, bytes_on_device;
 	int64_t number_of_blocks, logloc = 0, logsize_in_bytes = 0;
+	int64_t requested_blocks = 0;
 	char logdev[255] = { '\0' };	/* Need to use a macro for this size */
 	int aggr_block_size = 0;
 	int phys_block_size = PBSIZE, logsize = 0;
-	HFILE dev_handle;
+	int dev_handle;
 	unsigned type_commit = JFS_GROUPCOMMIT;
 	bool verify_blocks = false;
 	bool no_questions_asked = false;
@@ -788,7 +790,7 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	if (optind != argc - 1) {
+	if ((optind < argc - 2) || (optind > argc - 1)) {
 		printf
 		    ("\nError: Device not specified or command format error\n");
 		mkfs_usage();
@@ -796,6 +798,7 @@ int main(int argc, char *argv[])
 	}
 
 	device_name = argv[optind];
+
 	/*
 	 * If we are only creating an external journal, set the
 	 * log device name for later formatting of the log device
@@ -804,6 +807,10 @@ int main(int argc, char *argv[])
 		strcpy(logdev, argv[optind]);
 	}
 
+	optind++;
+	if (optind < argc)
+		requested_blocks = atoll(argv[optind]);
+
 	/* Check for block device */
 	{
 		struct stat stat_data;
@@ -920,10 +927,26 @@ int main(int argc, char *argv[])
 	 * Size of filesystem in terms of block size
 	 */
 	number_of_blocks = number_of_bytes / aggr_block_size;
+
+	if (requested_blocks) {
+		if (requested_blocks > number_of_blocks) {
+			printf("Requested blocks exceed number of blocks on device: %lld.\n",
+			       number_of_blocks);
+			close(dev_handle);
+			return EINVAL;
+		} else if (requested_blocks < (MINJFS / aggr_block_size)) {
+			strcpy(msgstr, MINJFSTEXT);
+			msg_parms[0] = msgstr;
+			message_user(MSG_JFS_PART_SMALL, msg_parms, 1, JFS_MSG);
+			close(dev_handle);
+			return EINVAL;
+		}
+		number_of_blocks = requested_blocks;
+	}
 	DBG_TRACE(("number of blocks = %lld\n", number_of_blocks))
 
-	    /* now ask the user if he really wants to destoy his data */
-	    if (no_questions_asked == false) {
+	/* now ask the user if he really wants to destroy his data */
+	if (no_questions_asked == false) {
 		if (ext_journal_opt != create_journal_only) {
 			msg_parms[0] = device_name;
 			message_user(MSG_OSO_DESTROY_DATA, msg_parms, 1,
@@ -1071,6 +1094,7 @@ int main(int argc, char *argv[])
 			      aggr_block_size, phys_block_size,
 			      type_jfs | type_commit, logdev, logloc, logsize,
 			      verify_blocks, log_uuid);
+	ujfs_flush_dev(dev_handle);
 	close(dev_handle);
 	/* Format Complete message */
 	if (rc == 0) {
