@@ -40,7 +40,7 @@ unsigned type_jfs;
 
 /* Global Data */
 int bsize;			/* aggregate block size         */
-HFILE fd;			/* Used by libfs routines       */
+int fd;				/* Used by libfs routines       */
 short l2bsize;			/* log2 of aggregate block size */
 int64_t AIT_2nd_offset;		/* Used by find_iag routines    */
 int64_t fsckwsp_offset;		/* Used by fsckcbbl routines    */
@@ -135,10 +135,9 @@ int main(int argc, char **argv)
 				inode();
 			else if (cmd_len > 3 && strncmp(command, "logsuper", cmd_len) == 0)
 				logsuper();
-			else if (strncmp(command, "quit", cmd_len) == 0) {
-				close(fd);
-				exit(0);
-			} else if ((cmd_len > 1) && strncmp(command, "set", cmd_len) == 0) {
+			else if (strncmp(command, "quit", cmd_len) == 0)
+				break;
+			else if ((cmd_len > 1) && strncmp(command, "set", cmd_len) == 0) {
 				fputs("set command is not yet implemented.\n", stderr);
 			} else if ((cmd_len > 1) && strncmp(command, "superblock", cmd_len) == 0)
 				superblock();
@@ -153,6 +152,7 @@ int main(int argc, char **argv)
 		fflush(stdout);
 	}
       errorout:
+	ujfs_flush_dev(fd);
 	close(fd);
 	return 0;
 }
