@@ -42,7 +42,7 @@
 
 /* Global Data */
 extern int bsize;
-extern HFILE fd;
+extern int fd;
 extern short l2bsize;
 
 /* xpeek functions */
